@@ -24,7 +24,7 @@
 #include <QSvgRenderer>
 #include <QPainter>
 #include <QApplication>
-#include <QGSettings/QGSettings>
+#include <QGSettings>
 
 class SVGHandler : public QObject
 {
